@@ -1,22 +1,22 @@
-if [ ! -f /etc/pulse/client.conf ]
+if [ ! -e /etc/pulse/client.conf ]
 then
     /usr/bin/mkdir -p /etc/pulse
     /usr/bin/cp /etc/defaults/etc/pulse/client.conf /etc/pulse/client.conf
 fi
 
-if [ ! -f /etc/pulse/daemon.conf ]
+if [ ! -e /etc/pulse/daemon.conf ]
 then
     /usr/bin/mkdir -p /etc/pulse
     /usr/bin/cp /etc/defaults/etc/pulse/daemon.conf /etc/pulse/daemon.conf
 fi
 
-if [ ! -f /etc/pulse/default.pa ]
+if [ ! -e /etc/pulse/default.pa ]
 then
     /usr/bin/mkdir -p /etc/pulse
     /usr/bin/cp /etc/defaults/etc/pulse/default.pa /etc/pulse/default.pa
 fi
 
-if [ ! -f /etc/pulse/system.pa ]
+if [ ! -e /etc/pulse/system.pa ]
 then
     /usr/bin/mkdir -p /etc/pulse
     /usr/bin/cp /etc/defaults/etc/pulse/system.pa /etc/pulse/system.pa
